module.exports = defineTest({
	description: 'keep break statements if their label is included'
});
